using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.SqlClient;
using MySql.Data.MySqlClient;
using log4net.Config;
using log4net;

namespace mobiledata
{
    class SQLExecutor
    {
        public static SQLExecutor instance = new SQLExecutor();

        protected SQLExecutor()
        {
        }

        protected ILog logger = LogManager.GetLogger(typeof(SQLExecutor));

        public void execute(String queryTemplate, params QueryParam[] dbParams)
        {
            IDbConnection conn = null;
            IDbCommand cmd = null;
            IDbTransaction trans = null;
            try
            {
                logger.Info("Oppening a connection...");
                conn = MobileDataFactory.instance.createConnection();
                conn.Open();
                trans = conn.BeginTransaction();

                logger.Info("Creating a command...");
                cmd = conn.CreateCommand();
                cmd.CommandText = queryTemplate;

                if (logger.IsDebugEnabled)
                    logger.Debug("Setting parameters...");

                foreach (QueryParam p in dbParams)
                {
                    IDbDataParameter param = cmd.CreateParameter();
                    param.ParameterName = p.ParamName;
                    param.DbType = p.ParamType;
                    param.Value = p.Value;
                    cmd.Parameters.Add(param);
                }

                cmd.Prepare();
                logger.Info("Executing the query...");
                cmd.ExecuteNonQuery();

                trans.Commit();
                logger.Info("Done.");

            }
            finally
            {
                conn.Close();
            } 
        }

        public void execute()
        {
            execute("INSERT INTO student(ime, prezime) Values(@p1,@p2)",
                new QueryParam("@p1", DbType.String, "Nemanja"),
                new QueryParam("@p2", DbType.String, "Kojic")); 
        }
    }
}
